@@ -722,6 +722,18 @@ int XrdPssDir::Readdir(char *buff, int blen)
    return -XRDOSS_E8002;
 }
 
+/******************************************************************************/
+/*                               S t a t R e t                                */
+/******************************************************************************/
+int XrdPssDir::StatRet(struct stat *buff)
+{
+   if (!myDir) return -XRDOSS_E8002;
+
+   auto rc = XrdPosixXrootd::StatRet(myDir, buff);
+   if (rc) return -rc;
+   return XrdOssOK;
+}
+
 /******************************************************************************/
 /*                                 C l o s e                                  */
 /******************************************************************************/
