@@ -271,7 +271,7 @@ void XrdXrootdTransit::Init(XrdXrootd::Bridge::Result *respP, // Private
 
 // Indicate that this brige supports asynchronous responses
 //
-   CapVer = kXR_asyncap | kXR_ver002;
+   CapVer = (kXR_char) kXR_asyncap | (kXR_char) kXR_ver002;
 
 // Mark the client as IPv4 if they came in as IPv4 or mapped IPv4. Note
 // there is no way we can figure out if this is a dual-stack client.
@@ -449,6 +449,11 @@ void XrdXrootdTransit::Redrive()
                                 {(char *)&eText,sizeof(eText)}};
    int rc;
 
+// Do some tracing
+//
+   TRACEP(REQ, "Bridge redrive runStatus="<<runStatus<<" runError="<<runError
+               <<" runWait="<<runWait<<" runWTot="<<runWTot);
+
 // Update wait statistics
 //
    runWTot += runWait;
@@ -457,11 +462,20 @@ void XrdXrootdTransit::Redrive()
 // While we are running asynchronously, there is no way that this object can
 // be deleted while a timer is outstanding as the link has been disabled. So,
 // we can reissue the request with little worry.
+//
+// This is a bit tricky here as a redriven request may result in a wait. If
+// this happens we cannot hand the result off to the real protocol until we
+// wait and successfully redrive. The wait handling occurs asynchronously
+// so all we need to do is honor it here.
 //
    if (!runALen || RunCopy(runArgs, runALen)) {
       do{rc = Process2();
-        if (rc == 0) {
+         TRACEP(REQ, "Bridge redrive Process2 rc="<<rc
+                     <<" runError="<<runError<<" runWait="<<runWait);
+        if (rc == 0 && !runWait && !runError) {
           rc = realProt->Process(NULL);
+          TRACEP(REQ, "Bridge redrive callback rc="<<rc
+                      <<" runStatus="<<runStatus);
         }
         if (runStatus)
            {AtomicBeg(runMutex);
